#  FlowScan.pm - a base class for scanning and reporting on flows
#  Copyright (C) 1998  Dave Plonka
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# $Id: FlowScan.pm,v 1.1 1999/01/04 19:49:46 plonka Exp $
# Dave Plonka <plonka@doit.wisc.edu>

use strict;

package FlowScan;

require 5;
require Exporter;

@FlowScan::ISA=qw(Exporter);
@FlowScan::EXPORT_OK=qw(ip2name);
# convert the RCS revision to a reasonable Exporter VERSION:
'$Revision: 1.1 $' =~ m/(\d+)\.(\d+)/ && (( $FlowScan::VERSION ) = sprintf("%d.%03d", $1, $2));

=head1 NAME

FlowScan -

=head1 SYNOPSIS

   $ flowscan FlowScanDerivedClass [...]

=head1 DESCRIPTION

This package implements a base-class solely for use with the flowscan utility.
Once you author derived classes, those class names are passed as arguments.

The following methods and subroutines are defined:

=over 4

=cut

=item new

The B<new> method constructs and returns a B<FlowScan> object.
You must define a report method in your derived class.

=cut

sub new {
   die "you must define a new method in your derived class!\n"
}

=item wanted

You must define a report method in your derived class.

=cut

sub wanted {
   die "you must define a wanted method in your derived class!\n"
}

=item perfile

You may define a perfile method in your derived class.

=cut

=item report

You must define a report method in your derived class.

=cut

sub report {
   die "you must define a report method in your derived class!\n"
}

=head1 BUGS

=head1 AUTHOR

Dave Plonka <plonka@doit.wisc.edu>

Copyright (C) 1998  Dave Plonka.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

=head1 VERSION

The version number is the module file RCS revision number (B<$Revision: 1.1 $>)
with the minor number printed right justified with leading zeroes to 3
decimal places.  For instance, RCS revision 1.1 would yield a package version
number of 1.001.

This is so that revision 1.10 (which is version 1.010), for example, will
test greater than revision 1.2 (which is version 1.002) when you want to
B<require> a minimum version of this module.

=cut

1
